from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from singlearity.api.ap_is_api import APIsApi
